==> lire_1.5.orig.tar.gz: lire-1.5/dnszone/po/lire-dnszone.pot.pl <==
# REFERENCE: dnszone.cfg
__( q{AXFR Totals} );
# REFERENCE: dnszone.cfg
__( q{AXFR Individuals} );
# REFERENCE: dnszone.cfg
__( q{Loaded zones} );
# REFERENCE: dnszone.cfg
__( q{Dynamic updates} );
# REFERENCE: schema:dnszone
__( q{DLF Schema for DNS Zone service} );
# REFERENCE: schema:dnszone
__( q{This DLF file is adequate to represent most common information about
  dnszone operations: approved/denied AXFR requests, completed zone transfers,
  loaded master and slave zones and denied dynamic DNS updates.  See also the
  bind8_named2dlf manpage for some more info on the dnszone DLF format.} );
# REFERENCE: schema:dnszone
__( q{Server} );
# REFERENCE: schema:dnszone
__( q{Name of the DNS server.} );
# REFERENCE: schema:dnszone
__( q{Timestamp} );
# REFERENCE: schema:dnszone
__( q{The time of the event.} );
# REFERENCE: schema:dnszone
__( q{Client Host} );
# REFERENCE: schema:dnszone
__( q{IP address of the host requesting the AXFR.} );
# REFERENCE: schema:dnszone
__( q{Zone} );
# REFERENCE: schema:dnszone
__( q{Name of the zone being requested.  E.g. foo.example.com.} );
# REFERENCE: schema:dnszone
__( q{Result} );
# REFERENCE: schema:dnszone
__( q{Either approved, denied or axfr.} );
# REFERENCE: schema:dnszone
__( q{Zone} );
# REFERENCE: schema:dnszone
__( q{Name of the zone just loaded. E.g. foo.example.com.} );
# REFERENCE: schema:dnszone
__( q{Serial} );
# REFERENCE: schema:dnszone
__( q{Serial of the zone just loaded, as in the DNS SOA record. E.g.
     2002071301 or 1024654055.} );
# REFERENCE: schema:dnszone
__( q{Role} );
# REFERENCE: schema:dnszone
__( q{Either master or slave.} );
# REFERENCE: schema:dnszone
__( q{Client Host} );
# REFERENCE: schema:dnszone
__( q{IP address of the host requesting the update.} );
# REFERENCE: schema:dnszone
__( q{Zone} );
# REFERENCE: schema:dnszone
__( q{Name of the zone being updated.} );
# REFERENCE: report:dnszone:top-axfr-host
__( q{Top Requesting AXFR Hosts Report} );
# REFERENCE: report:dnszone:top-axfr-host
__( q{This report lists the requesting hosts with the most requests.} );
# REFERENCE: report:dnszone:top-axfr-host
__( q{This parameter controls the number of hosts to
     display in the report.
    } );
# REFERENCE: report:dnszone:top-axfr-host
__( q{Number of AXFRs by Hosts, Top $hosts_to_show} );
# REFERENCE: report:dnszone:top-axfr-host
__( q{Transfers} );
# REFERENCE: report:dnszone:top-axfr-host
__( q{% Total} );
# REFERENCE: report:dnszone:top-axfr-zone
__( q{Top Requesting AXFR Hosts Report} );
# REFERENCE: report:dnszone:top-axfr-zone
__( q{This report lists the requesting hosts with the most requests.} );
# REFERENCE: report:dnszone:top-axfr-zone
__( q{This parameter controls the number of hosts to
     display in the report.
    } );
# REFERENCE: report:dnszone:top-axfr-zone
__( q{Number of AXFRs by zone, Top $zones_to_show} );
# REFERENCE: report:dnszone:top-axfr-zone
__( q{Transfers} );
# REFERENCE: report:dnszone:top-axfr-zone
__( q{% Total} );
# REFERENCE: report:dnszone:top-axfr
__( q{Top Requesting AXFR Hosts Report} );
# REFERENCE: report:dnszone:top-axfr
__( q{This report lists the requesting hosts with the most requests.} );
# REFERENCE: report:dnszone:top-axfr
__( q{This parameter controls the number of zones to
     display in the report.
    } );
# REFERENCE: report:dnszone:top-axfr
__( q{This parameter controls the number of hosts to
     display in the report.
    } );
# REFERENCE: report:dnszone:top-axfr
__( q{Number of performed AXFRs by zone (top $zones_to_show) with hosts requesting (top $hosts_to_show)} );
# REFERENCE: report:dnszone:top-axfr
__( q{Transfers} );
# REFERENCE: report:dnszone:top-axfr
__( q{% Total} );
# REFERENCE: report:dnszone:top-axfr
__( q{% Group} );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{Top Denied AXFR Requests} );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{This report lists the top 10 of denied AXFR requests.} );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{This parameter controls the number of zones to
     display in the report.
    } );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{This parameter controls the number of hosts to
     display in the report.
    } );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{Number of denied AXFRs by zone, Top $zones_to_show} );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{Denied Transfers} );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{% Total} );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{% Group} );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{Top Denied Dynamic DNS Updates Report} );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{This report lists the top of the denied dynamic DNS packets.} );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{This parameter controls the number of zones to
     display in the report.
    } );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{This parameter controls the number of hosts to
     display in the report.
    } );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{Number of Denied Dynamic DNS Updates Zones by Zone, Top $zones_to_show} );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{Denied Updates} );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{% Total} );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{% Group} );
# REFERENCE: report:dnszone:top-loadedzone
__( q{Top Newly Loaded Zones Report} );
# REFERENCE: report:dnszone:top-loadedzone
__( q{This report lists the top of the newly loaded zones.} );
# REFERENCE: report:dnszone:top-loadedzone
__( q{This parameter controls the number of zones to
     display in the report.
    } );
# REFERENCE: report:dnszone:top-loadedzone
__( q{Number of times a zone has been loaded (Top $zones_to_show)} );
# REFERENCE: report:dnszone:top-loadedzone
__( q{Reloads} );
# REFERENCE: report:dnszone:top-loadedzone
__( q{% Total} );
# REFERENCE: report:dnszone:top-loadedzone
__( q{% Group} );
# REFERENCE: filter:dnszone:axfr-approved-only
__( q{AXFR denied only} );
# REFERENCE: filter:dnszone:axfr-approved-only
__( q{This filter specification filters out the non-approved AXFR lines.
  } );
# REFERENCE: filter:dnszone:axfr-approved-only
__( q{AXFR denied only} );
# REFERENCE: filter:dnszone:axfr-axfr-only
__( q{AXFR denied only} );
# REFERENCE: filter:dnszone:axfr-axfr-only
__( q{This filter specification filters out the transfered AXFR lines.
  } );
# REFERENCE: filter:dnszone:axfr-axfr-only
__( q{AXFR transfered only} );
# REFERENCE: filter:dnszone:axfr-denied-only
__( q{AXFR denied only} );
# REFERENCE: filter:dnszone:axfr-denied-only
__( q{This filter specification filters out the non-approved AXFR lines.
  } );
# REFERENCE: filter:dnszone:axfr-denied-only
__( q{AXFR denied only} );
# REFERENCE: filter:dnszone:dyndns-only
__( q{Loaded zones only} );
# REFERENCE: filter:dnszone:dyndns-only
__( q{This filter specification filters out the non-dynamic DNS entries.
  } );
# REFERENCE: filter:dnszone:dyndns-only
__( q{Dynamic Updates only} );
# REFERENCE: filter:dnszone:loaded-only
__( q{Loaded zones only} );
# REFERENCE: filter:dnszone:loaded-only
__( q{This filter specification filters out the non-loaded zones.
  } );
# REFERENCE: filter:dnszone:loaded-only
__( q{Loaded zones only} );

==> lire_2.0.1.orig.tar.gz: lire-2.0.1/dnszone/po/lire-dnszone.pot.pl <==
# REFERENCE: dnszone_default.xml
__( q{AXFR Totals} );
# REFERENCE: dnszone_default.xml
__( q{AXFR Individuals} );
# REFERENCE: dnszone_default.xml
__( q{Loaded zones} );
# REFERENCE: dnszone_default.xml
__( q{Dynamic updates} );
# REFERENCE: schema:dnszone
__( q{DLF Schema for DNS Zone service} );
# REFERENCE: schema:dnszone
__( q{This DLF file is adequate to represent most common information about dnszone operations: approved/denied AXFR requests, completed zone transfers, loaded master and slave zones and denied dynamic DNS updates.  See also the bind8_named2dlf manpage for some more info on the dnszone DLF format.} );
# REFERENCE: schema:dnszone
__( q{Server} );
# REFERENCE: schema:dnszone
__( q{Name of the DNS server.} );
# REFERENCE: schema:dnszone
__( q{Timestamp} );
# REFERENCE: schema:dnszone
__( q{The time of the event.} );
# REFERENCE: schema:dnszone
__( q{Client Host} );
# REFERENCE: schema:dnszone
__( q{IP address of the host requesting the AXFR.} );
# REFERENCE: schema:dnszone
__( q{Zone} );
# REFERENCE: schema:dnszone
__( q{Name of the zone being requested.  E.g. foo.example.com.} );
# REFERENCE: schema:dnszone
__( q{Result} );
# REFERENCE: schema:dnszone
__( q{Either approved, denied or axfr.} );
# REFERENCE: schema:dnszone
__( q{Zone} );
# REFERENCE: schema:dnszone
__( q{Name of the zone just loaded. E.g. foo.example.com.} );
# REFERENCE: schema:dnszone
__( q{Serial} );
# REFERENCE: schema:dnszone
__( q{Serial of the zone just loaded, as in the DNS SOA record. E.g. 2002071301 or 1024654055.} );
# REFERENCE: schema:dnszone
__( q{Role} );
# REFERENCE: schema:dnszone
__( q{Either master or slave.} );
# REFERENCE: schema:dnszone
__( q{Client Host} );
# REFERENCE: schema:dnszone
__( q{IP address of the host requesting the update.} );
# REFERENCE: schema:dnszone
__( q{Zone} );
# REFERENCE: schema:dnszone
__( q{Name of the zone being updated.} );
# REFERENCE: report:dnszone:top-axfr-host
__( q{Top Requesting AXFR Hosts Report} );
# REFERENCE: report:dnszone:top-axfr-host
__( q{This report lists the requesting hosts with the most requests.} );
# REFERENCE: report:dnszone:top-axfr-host
__( q{This parameter controls the number of hosts to display in the report. } );
# REFERENCE: report:dnszone:top-axfr-host
__( q{Number of AXFRs by Hosts, Top $hosts_to_show} );
# REFERENCE: report:dnszone:top-axfr-host
__( q{Transfers} );
# REFERENCE: report:dnszone:top-axfr-host
__( q{% Total} );
# REFERENCE: report:dnszone:top-axfr-zone
__( q{Top Requesting AXFR Hosts Report} );
# REFERENCE: report:dnszone:top-axfr-zone
__( q{This report lists the requesting hosts with the most requests.} );
# REFERENCE: report:dnszone:top-axfr-zone
__( q{This parameter controls the number of hosts to display in the report. } );
# REFERENCE: report:dnszone:top-axfr-zone
__( q{Number of AXFRs by zone, Top $zones_to_show} );
# REFERENCE: report:dnszone:top-axfr-zone
__( q{Transfers} );
# REFERENCE: report:dnszone:top-axfr-zone
__( q{% Total} );
# REFERENCE: report:dnszone:top-axfr
__( q{Top Requesting AXFR Hosts Report} );
# REFERENCE: report:dnszone:top-axfr
__( q{This report lists the requesting hosts with the most requests.} );
# REFERENCE: report:dnszone:top-axfr
__( q{This parameter controls the number of zones to display in the report. } );
# REFERENCE: report:dnszone:top-axfr
__( q{This parameter controls the number of hosts to display in the report. } );
# REFERENCE: report:dnszone:top-axfr
__( q{Number of performed AXFRs by zone (top $zones_to_show) with hosts requesting (top $hosts_to_show)} );
# REFERENCE: report:dnszone:top-axfr
__( q{Transfers} );
# REFERENCE: report:dnszone:top-axfr
__( q{% Total} );
# REFERENCE: report:dnszone:top-axfr
__( q{% Group} );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{Top Denied AXFR Requests} );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{This report lists the top 10 of denied AXFR requests.} );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{This parameter controls the number of zones to display in the report. } );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{This parameter controls the number of hosts to display in the report. } );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{Number of denied AXFRs by zone, Top $zones_to_show} );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{Denied Transfers} );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{% Total} );
# REFERENCE: report:dnszone:top-denied-axfr
__( q{% Group} );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{Top Denied Dynamic DNS Updates Report} );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{This report lists the top of the denied dynamic DNS packets.} );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{This parameter controls the number of zones to display in the report. } );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{This parameter controls the number of hosts to display in the report. } );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{Number of Denied Dynamic DNS Updates Zones by Zone, Top $zones_to_show} );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{Denied Updates} );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{% Total} );
# REFERENCE: report:dnszone:top-dynamicdenied
__( q{% Group} );
# REFERENCE: report:dnszone:top-loadedzone
__( q{Top Newly Loaded Zones Report} );
# REFERENCE: report:dnszone:top-loadedzone
__( q{This report lists the top of the newly loaded zones.} );
# REFERENCE: report:dnszone:top-loadedzone
__( q{This parameter controls the number of zones to display in the report. } );
# REFERENCE: report:dnszone:top-loadedzone
__( q{Number of times a zone has been loaded (Top $zones_to_show)} );
# REFERENCE: report:dnszone:top-loadedzone
__( q{Reloads} );
# REFERENCE: report:dnszone:top-loadedzone
__( q{% Total} );
# REFERENCE: report:dnszone:top-loadedzone
__( q{% Group} );
# REFERENCE: filter:dnszone:axfr-approved-only
__( q{AXFR denied only} );
# REFERENCE: filter:dnszone:axfr-approved-only
__( q{This filter specification filters out the non-approved AXFR lines. } );
# REFERENCE: filter:dnszone:axfr-approved-only
__( q{AXFR denied only} );
# REFERENCE: filter:dnszone:axfr-axfr-only
__( q{AXFR denied only} );
# REFERENCE: filter:dnszone:axfr-axfr-only
__( q{This filter specification filters out the transfered AXFR lines. } );
# REFERENCE: filter:dnszone:axfr-axfr-only
__( q{AXFR transfered only} );
# REFERENCE: filter:dnszone:axfr-denied-only
__( q{AXFR denied only} );
# REFERENCE: filter:dnszone:axfr-denied-only
__( q{This filter specification filters out the non-approved AXFR lines. } );
# REFERENCE: filter:dnszone:axfr-denied-only
__( q{AXFR denied only} );
# REFERENCE: filter:dnszone:dyndns-only
__( q{Loaded zones only} );
# REFERENCE: filter:dnszone:dyndns-only
__( q{This filter specification filters out the non-dynamic DNS entries. } );
# REFERENCE: filter:dnszone:dyndns-only
__( q{Dynamic Updates only} );
# REFERENCE: filter:dnszone:loaded-only
__( q{Loaded zones only} );
# REFERENCE: filter:dnszone:loaded-only
__( q{This filter specification filters out the non-loaded zones. } );
# REFERENCE: filter:dnszone:loaded-only
__( q{Loaded zones only} );
